@@ -1,3 +1,45 @@
+"""
+/******************************************************************************
+ * $Id: core.py 889 2008-09-28 04:17:22Z hobu $
+ *
+ * Project:  libLAS - http://liblas.org - A BSD library for LAS format data.
+ * Purpose:  Python ctypes function calls
+ * Author:   Howard Butler, hobu.inc@gmail.com
+ *
+ ******************************************************************************
+ * Copyright (c) 2008, Howard Butler
+ *
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without 
+ * modification, are permitted provided that the following 
+ * conditions are met:
+ * 
+ *     * Redistributions of source code must retain the above copyright 
+ *       notice, this list of conditions and the following disclaimer.
+ *     * Redistributions in binary form must reproduce the above copyright 
+ *       notice, this list of conditions and the following disclaimer in 
+ *       the documentation and/or other materials provided 
+ *       with the distribution.
+ *     * Neither the name of the Martin Isenburg or Iowa Department 
+ *       of Natural Resources nor the names of its contributors may be 
+ *       used to endorse or promote products derived from this software 
+ *       without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
+ * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
+ * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
+ * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT 
+ * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
+ * OF SUCH DAMAGE.
+ ****************************************************************************/
+ """
 import atexit, os, re, sys
 import ctypes
 from ctypes.util import find_library
@@ -62,7 +104,7 @@ except ImportError:
 if os.name == 'nt':
     # stolen from Shapely
     # http://trac.gispython.org/projects/PCL/browser/Shapely/trunk/shapely/geos.py
-    lib_name = 'liblas0.9.6.dll'
+    lib_name = 'liblas1.dll'
     try:
         local_dlls = os.path.abspath(os.__file__ + "../../../DLLs")
         original_path = os.environ['PATH']
@@ -275,18 +317,18 @@ las.LASHeader_GetReserved.restype = ctypes.c_short
 las.LASHeader_GetReserved.argtypes = [ctypes.c_void_p]
 las.LASHeader_GetReserved.errcheck = check_value
 
-las.LASHeader_GetCreationDOY.restype = ctypes.c_short
+las.LASHeader_GetCreationDOY.restype = ctypes.c_ushort
 las.LASHeader_GetCreationDOY.argtypes = [ctypes.c_void_p]
 las.LASHeader_GetCreationDOY.errcheck = check_value
 las.LASHeader_SetCreationDOY.restype = ctypes.c_int
-las.LASHeader_SetCreationDOY.argtypes = [ctypes.c_void_p, ctypes.c_short]
+las.LASHeader_SetCreationDOY.argtypes = [ctypes.c_void_p, ctypes.c_ushort]
 las.LASHeader_SetCreationDOY.errcheck = check_return
 
-las.LASHeader_GetCreationYear.restype = ctypes.c_short
+las.LASHeader_GetCreationYear.restype = ctypes.c_ushort
 las.LASHeader_GetCreationYear.argtypes = [ctypes.c_void_p]
 las.LASHeader_GetCreationYear.errcheck = check_value
 las.LASHeader_SetCreationYear.restype = ctypes.c_int
-las.LASHeader_SetCreationYear.argtypes = [ctypes.c_void_p, ctypes.c_short]
+las.LASHeader_SetCreationYear.argtypes = [ctypes.c_void_p, ctypes.c_ushort]
 las.LASHeader_SetCreationYear.errcheck = check_return
 
 las.LASHeader_GetHeaderSize.restype = ctypes.c_ushort
@@ -379,6 +421,22 @@ las.LASHeader_SetMax.restype = ctypes.c_int
 las.LASHeader_SetMax.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_double, ctypes.c_double]
 las.LASHeader_SetMax.errcheck = check_return
 
+las.LASHeader_GetProj4.argtypes = [ctypes.c_void_p]
+las.LASHeader_GetProj4.errcheck = check_value_free
+las.LASHeader_SetProj4.restype = ctypes.c_int
+las.LASHeader_SetProj4.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+las.LASHeader_SetProj4.errcheck = check_return
+
+las.LASHeader_GetVLR.argtypes = [ctypes.c_void_p, ctypes.c_int]
+las.LASHeader_GetVLR.errcheck = check_void
+las.LASHeader_GetVLR.restype = ctypes.c_void_p
+
+las.LASHeader_DeleteVLR.argtypes = [ctypes.c_void_p, ctypes.c_int]
+las.LASHeader_DeleteVLR.errcheck = check_return
+
+las.LASHeader_AddVLR.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+las.LASHeader_AddVLR.errcheck = check_return
+
 las.LASWriter_Create.restype = ctypes.c_void_p
 las.LASWriter_Create.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_int]
 las.LASWriter_Create.errcheck = check_void
@@ -418,3 +476,49 @@ las.LASHeader_SetGUID.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
 las.LASHeader_SetGUID.errcheck = check_value
 las.LASHeader_SetGUID.restype = ctypes.c_int
 
+las.LASVLR_Create.errcheck = check_void
+las.LASVLR_Create.restype = ctypes.c_void_p
+
+las.LASVLR_Destroy.argtypes = [ctypes.c_void_p]
+las.LASVLR_Destroy.errcheck = check_void_done
+
+las.LASVLR_GetUserId.argtypes = [ctypes.c_void_p]
+las.LASVLR_GetUserId.errcheck = check_value_free
+las.LASVLR_SetUserId.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+las.LASVLR_SetUserId.errcheck = check_return
+las.LASVLR_SetUserId.restype = ctypes.c_int
+
+las.LASVLR_GetDescription.argtypes = [ctypes.c_void_p]
+las.LASVLR_GetDescription.errcheck = check_value_free
+las.LASVLR_SetDescription.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+las.LASVLR_SetDescription.errcheck = check_return
+las.LASVLR_SetDescription.restype = ctypes.c_int
+
+las.LASVLR_GetRecordLength.argtypes = [ctypes.c_void_p]
+las.LASVLR_GetRecordLength.errcheck = check_value
+las.LASVLR_GetRecordLength.restype = ctypes.c_ushort
+las.LASVLR_SetRecordLength.argtypes = [ctypes.c_void_p, ctypes.c_ushort]
+las.LASVLR_SetRecordLength.errcheck = check_return
+las.LASVLR_SetRecordLength.restype = ctypes.c_int
+
+las.LASVLR_GetRecordId.argtypes = [ctypes.c_void_p]
+las.LASVLR_GetRecordId.errcheck = check_value
+las.LASVLR_GetRecordId.restype = ctypes.c_ushort
+las.LASVLR_SetRecordId.argtypes = [ctypes.c_void_p, ctypes.c_ushort]
+las.LASVLR_SetRecordId.errcheck = check_return
+las.LASVLR_SetRecordId.restype = ctypes.c_int
+
+las.LASVLR_GetReserved.argtypes = [ctypes.c_void_p]
+las.LASVLR_GetReserved.errcheck = check_value
+las.LASVLR_GetReserved.restype = ctypes.c_ushort
+las.LASVLR_SetReserved.argtypes = [ctypes.c_void_p, ctypes.c_ushort]
+las.LASVLR_SetReserved.errcheck = check_return
+las.LASVLR_SetReserved.restype = ctypes.c_int
+
+las.LASVLR_GetData.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_ubyte)]
+las.LASVLR_GetData.errcheck = check_value
+las.LASVLR_GetData.restype = ctypes.c_int
+
+las.LASVLR_SetData.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_ubyte)]
+las.LASVLR_SetData.errcheck = check_value
+las.LASVLR_SetData.restype = ctypes.c_int
\ No newline at end of file
